@@ -184,7 +184,7 @@ def parse_authentication_results(authentication_results: Union[str, List],
     """
     def parse_result(authentication_results_, from_domain_):
         authentication_results_ = authentication_results_.lower()
-        authentication_results_ = re.sub(r"\n\s+", " ",
+        authentication_results_ = re.sub(r"(\n|\r\n)\s+", " ",
                                          authentication_results_)
         parts = authentication_results_.split(";")
         parsed_parts = {}
@@ -251,7 +251,7 @@ def parse_dkim_signature(dkim_signature: Union[str, List]) -> Union[Dict,
     """
     def parse_header(dkim_signature_: str) -> Dict:
         parsed_signature = {}
-        dkim_signature_ = re.sub(r"\n\s+", " ", dkim_signature_)
+        dkim_signature_ = re.sub(r"(\n|\r\n)\s+", " ", dkim_signature_)
         parts = dkim_signature_.split(";")
         for part in parts:
             key_value = part.split("=")
@@ -261,7 +261,10 @@ def parse_dkim_signature(dkim_signature: Union[str, List]) -> Union[Dict,
                 parsed_signature[key] = value
 
         if "h" in parsed_signature:
-            parsed_signature["h"] = parsed_signature["h"].split(":")
+            signed_headers = parsed_signature["h"].split(":")
+            for _i in range(len(signed_headers)):
+                signed_headers[_i] = signed_headers[_i].strip()
+            parsed_signature["h"] = signed_headers
 
         return parsed_signature
 
@@ -322,9 +325,9 @@ def parse_email(data: Union[str, bytes],
     parsed_email = _parsed_email.mail
     if isinstance(parsed_email, str):
         raise ValueError("Not an email")
-    headers_str = data.split("\n\n")[0]
+    headers_str = re.split(r"(\n|\r\n){2,}", data)[0]
     parsed_email["raw_headers"] = headers_str
-    headers_str = re.sub(r"\n\s+", " ", headers_str)
+    headers_str = re.sub(r"(\n|\r\n)\s+", " ", headers_str)
     if "subject" in parsed_email:
         headers_str = re.sub(r"Subject: .+",
                              f"Subject: {parsed_email['subject']}",
@@ -337,7 +340,10 @@ def parse_email(data: Union[str, bytes],
     parsed_email["headers_string"] = headers_str
     from_domain = None
     if parsed_email["from"] is not None:
-        parsed_email["from"] = parse_email_address(parsed_email["from"][0])
+        for entry in parsed_email["from"]:
+            if "@" in entry[1]:
+                parsed_email["from"] = parse_email_address(entry)
+                break
         from_domain = parsed_email["from"]["domain"]
     if "dkim-signature" in parsed_email:
         try:
@@ -526,7 +532,7 @@ def from_trusted_domain(message: Union[str, IOBase, Dict],
         parsed_email = parse_email(message)
 
     if isinstance(trusted_domains, str):
-        trusted_domains.split("\n")
+        trusted_domains = re.split(r"(\n|\r\n)", trusted_domains)
 
     for i in range(len(trusted_domains)):
         trusted_domains[i] = trusted_domains[i].lower().strip()
